package com.example.mmad.testapp.query;

import com.example.mmad.testapp.entity.UserQueryEntity;
import com.example.mmad.testapp.event.UserCreatedEvent;
import com.example.mmad.testapp.kafkaProducerConfig.KafkaProducerConfig;
import com.example.mmad.testapp.repository.UserReadRepository;
import org.springframework.context.event.EventListener;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

@Component
public class UserQueryHandler {
    private static final String kafkaTopic = "user-created";
    private final KafkaProducerConfig kafkaProducer;
    private final UserReadRepository userReadRepository;

    public UserQueryHandler(KafkaProducerConfig kafkaProducer, UserReadRepository userReadRepository) {
        this.kafkaProducer = kafkaProducer;
        this.userReadRepository = userReadRepository;
    }

    @Async("taskExecutor")
    @EventListener
    public void handelUserCreated(UserCreatedEvent event) {
        kafkaProducer.kafkaTemplate().send(kafkaTopic, event);
        UserQueryEntity userQueryEntity = new UserQueryEntity();
        userQueryEntity.setId(event.getUserId());
        userQueryEntity.setUserName(event.getUsername());
        userQueryEntity.setEmail(event.getEmail());
        //TODO mapper needed
        userReadRepository.save(userQueryEntity);
        System.out.println("Received user created event" + event.getUserId());
    }
}
